@@ -30,7 +30,7 @@ from pyubx2.ubxhelpers import (
 class UBXMessage:
     """UBX Message Class."""
 
-    def __init__(self, ubxClass, ubxID, mode: int, **kwargs):
+    def __init__(self, ubxClass, ubxID, msgmode: int, **kwargs):
         """Constructor.
 
         If no keyword parms are passed, the payload is taken to be empty.
@@ -43,7 +43,7 @@ class UBXMessage:
 
         :param object msgClass: message class as str, int or byte
         :param object msgID: message ID as str, int or byte
-        :param int mode: mode (0=GET, 1=SET, 2=POLL)
+        :param int msgmode: message mode (0=GET, 1=SET, 2=POLL)
         :param kwargs: optional payload key/value pairs
         :raises: UBXMessageError
 
@@ -51,13 +51,13 @@ class UBXMessage:
 
         # object is mutable during initialisation only
         super().__setattr__("_immutable", False)
-        self._mode = mode
+        self._mode = msgmode
         self._payload = b""
         self._length = b""
         self._checksum = b""
 
-        if mode not in (0, 1, 2):
-            raise ube.UBXMessageError(f"Invalid mode {mode} - must be 0, 1 or 2")
+        if msgmode not in (0, 1, 2):
+            raise ube.UBXMessageError(f"Invalid msgmode {msgmode} - must be 0, 1 or 2.")
 
         # accommodate different formats of msgClass and msgID
         if isinstance(ubxClass, str) and isinstance(
@@ -221,15 +221,11 @@ class UBXMessage:
             valb = self._payload[offset : offset + atts]
             val = self.bytes2val(valb, att)
         else:
-            # if individual attribute keyword has been provided
-            if keyr in kwargs:
-                val = kwargs[keyr]
-            # else set attribute to nominal value (0)
-            else:
-                if atttyp(att) in ("X", "C"):  # byte or char
-                    val = b"\x00" * atts
-                else:
-                    val = 0
+            # if individual keyword has been provided,
+            # set to provided value, else set to
+            # nominal value
+            val = kwargs.get(keyr, self.nomval(att))
+
             valb = self.val2bytes(val, att)
             self._payload += valb
 
@@ -483,7 +479,7 @@ class UBXMessage:
             raise ube.UBXMessageError(
                 "ESF-MEAS message definitions must include flags or payload keyword"
             )
-        calibTtagValid = get_bits(flags, 8)  # get bit 3 in flags
+        calibTtagValid = get_bits(flags, 0b00001000)  # get bit 3 in flags
         if calibTtagValid:
             pdict = ubg.UBX_PAYLOADS_GET["ESF-MEAS-CT"]
         else:
@@ -491,7 +487,7 @@ class UBXMessage:
         return pdict
 
     def _calc_num_repeats(
-        self, att: str, payload: bytes, offset: int, offsetend: int = 0
+        self, attd: dict, payload: bytes, offset: int, offsetend: int = 0
     ) -> int:
         """
         Deduce number of items in 'variable by size' repeating group by
@@ -500,7 +496,7 @@ class UBXMessage:
         This is predicated on there being only one such repeating group
         per message payload, which is true for all currently supported types.
 
-        :param str att: attribute type e.g. 'U004'
+        :param dict attd: grouped attribute dictionary
         :param bytes payload : raw payload
         :param int offset: number of bytes in payload before repeating group
         :param int offsetend: number of bytes in payload after repeating group
@@ -512,7 +508,7 @@ class UBXMessage:
 
         lenpayload = len(payload) - offset - offsetend
         lengroup = 0
-        for _, val in att.items():
+        for _, val in attd.items():
             lengroup += attsiz(val)
         return int(lenpayload / lengroup)
 
@@ -779,6 +775,30 @@ class UBXMessage:
             raise ube.UBXTypeError(f"Unknown attribute type {att}")
         return val
 
+    @staticmethod
+    def nomval(att: str) -> object:
+        """
+        Get nominal value for given UBX attribute type.
+
+        :param str att: attribute type e.g. 'U004'
+        :return: attribute value as int, float, str or bytes
+        :rtype: object
+        :raises: UBXTypeError
+
+        """
+
+        if att == "CH":
+            val = ""
+        elif atttyp(att) in ("X", "C"):
+            val = b"\x00" * attsiz(att)
+        elif atttyp(att) == "R":
+            val = 0.0
+        elif atttyp(att) in ("E", "I", "L", "U"):
+            val = 0
+        else:
+            raise ube.UBXTypeError(f"Unknown attribute type {att}")
+        return val
+
     @staticmethod
     def cfgname2key(name: str) -> tuple:
         """
